using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.IO;

namespace ClienteDeEscritorioFotos
{
  public partial class Aadir : Form
  {
    public Aadir()
    {
      InitializeComponent();
    }

    private void btExaminar_Click(object sender, EventArgs e)
    {
      OpenFileDialog DlgAbrir = new OpenFileDialog();

      DlgAbrir.InitialDirectory = System.IO.Directory.GetCurrentDirectory();
      DlgAbrir.Filter =
        "Ficheros BMP|*.bmp;*.BMP"+
        "|Ficheros GIF|*.gif;*.GIF"+
        "|Ficheros JPG o JPEG|*.jpg;*.JPG;*.jpeg;*.JPEG"+
        "|Ficheros PNG|*.png;*.PNG"+
        "|Ficheros EXIF|*.exif;*.EXIF"+
        "|Ficheros TIFF|*.tiff;*.TIFF"+
        "|(*.*)|*.*";
      DlgAbrir.FilterIndex = 3;

      // Mostrar el dilogo Abrir
      if (DlgAbrir.ShowDialog() == DialogResult.OK)
      {
        ctRutaFoto.Text = DlgAbrir.FileName;
      }
    }

    private void btAadir_Click(object sender, EventArgs e)
    {
      if (FormularioCorrecto())
      {
        string sMessageRet = string.Empty; // mensaje de retorno
        FileInfo fFoto = new FileInfo(ctRutaFoto.Text.Trim());
        if (fFoto.Exists)
        {
          try
          {
            // Almacenamos la imagen en un array de bytes para
            // enviarla al servidor
            byte[] bImg = new byte[fFoto.Length];
            FileStream fsStream = null;
            int iBytesRead = 0;
            try
            {
              fsStream = fFoto.Open(FileMode.Open);
              iBytesRead = fsStream.Read(bImg, 0, (int)fsStream.Length);
            }
            catch (Exception ex)
            {
              MessageBox.Show(this, "No se puede acceder a la foto.\n\n" + ex.Message, "Error foto", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
              fsStream.Close();
            }

            if (iBytesRead == 0) return;

            // Invocar al mtodo del servicio Web que permite almacenar
            // la foto en la base de datos.
            // servicio.AgregarFoto(
            //   fFoto.Name, ctNombre.Text, ctAutor.Name, ctDescripcion.Text, bImg)
            MessageBox.Show("La foto ha sido aadida a la base de datos");
          }
          catch
          {
            MessageBox.Show(this, "Error al aadir la foto: " + ctNombre.Text, "Nueva foto", MessageBoxButtons.OK, MessageBoxIcon.Error);
          }
        }
      }
    }

    protected bool FormularioCorrecto()
    {
      bool bArchivoCorrecto = true;
      bool bNombreCorrecto = true;
      bool bAutorCorrecto = true;
      string mensajeError = null;

      // Comprobamos los datos del formulario
      if (ctRutaFoto.Text.Length == 0)
      {
        mensajeError = "Seleccione un archivo";
        bArchivoCorrecto = false;
      }
      if (ctAutor.Text.Length == 0)
      {
        mensajeError += "\nDebe introducir un autor";
        bAutorCorrecto = false;
      }
      if (ctNombre.Text.Length == 0)
      {
        mensajeError += "\nDebe introducir un nombre";
        bNombreCorrecto = false;
      }

      if (!(bArchivoCorrecto && bNombreCorrecto && bAutorCorrecto))
        MessageBox.Show(mensajeError);
      return (bArchivoCorrecto && bNombreCorrecto && bAutorCorrecto);
    }
  }
}
