﻿using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using Npgsql;
using System.IO;

namespace ClienteDeEscritorioFotos
{
  public partial class Añadir : Form
  {
    public Añadir()
    {
      InitializeComponent();
    }

    private void btExaminar_Click(object sender, EventArgs e)
    {
      OpenFileDialog DlgAbrir = new OpenFileDialog();

      DlgAbrir.InitialDirectory = Directory.GetCurrentDirectory();
      DlgAbrir.Filter =
        "Ficheros BMP|*.bmp;*.BMP"+
        "|Ficheros GIF|*.gif;*.GIF"+
        "|Ficheros JPG o JPEG|*.jpg;*.JPG;*.jpeg;*.JPEG"+
        "|Ficheros PNG|*.png;*.PNG"+
        "|Ficheros EXIF|*.exif;*.EXIF"+
        "|Ficheros TIFF|*.tiff;*.TIFF"+
        "|(*.*)|*.*";
      DlgAbrir.FilterIndex = 3;

      // Mostrar el diálogo Abrir
      if (DlgAbrir.ShowDialog() == DialogResult.OK)
      {
        ctRutaFoto.Text = DlgAbrir.FileName;
      }
    }

    private void btAñadir_Click(object sender, EventArgs e)
    {
      if (FormularioCorrecto())
      {
        // Obtener la ruta de la caja de texto
        FileInfo fiFoto = new FileInfo(ctRutaFoto.Text.Trim());
        // Comprobar si el fichero existe
        if (fiFoto.Exists)
        {
          try
          {
            // Copiar en la carpeta fotos la foto seleccionada
            fiFoto.CopyTo(Mostrar.sRutaFotos + Mostrar.sCarpFotos +
              Path.DirectorySeparatorChar.ToString() + fiFoto.Name);
            // Añadir los datos relacionados con la foto a la BD
            Anadir_Foto(Mostrar.sCarpFotos + 
              Path.DirectorySeparatorChar.ToString() + fiFoto.Name,
              ctNombre.Text, ctAutor.Text, ctDescripcion.Text);

            MessageBox.Show(this, "Foto añadida: " + ctNombre.Text,
                            "Nueva foto", MessageBoxButtons.OK,
                            MessageBoxIcon.Information);

            this.Close();
          }
          catch
          {
            MessageBox.Show(this, "Error al añadir la foto: " + 
              ctNombre.Text, "Nueva foto",
              MessageBoxButtons.OK, MessageBoxIcon.Error);
          }
        }
      }
    }

    protected bool FormularioCorrecto()
    {
      bool bArchivoCorrecto = true;
      bool bNombreCorrecto = true;
      bool bAutorCorrecto = true;
      string mensajeError = null;

      // Comprobamos los datos del formulario
      if (ctRutaFoto.Text.Length == 0)
      {
        mensajeError = "Seleccione un archivo";
        bArchivoCorrecto = false;
      }
      if (ctAutor.Text.Length == 0)
      {
        mensajeError += "\nDebe introducir un autor";
        bAutorCorrecto = false;
      }
      if (ctNombre.Text.Length == 0)
      {
        mensajeError += "\nDebe introducir un nombre";
        bNombreCorrecto = false;
      }

      if (!(bArchivoCorrecto && bNombreCorrecto && bAutorCorrecto))
        MessageBox.Show(mensajeError);
      return (bArchivoCorrecto && bNombreCorrecto && bAutorCorrecto);
    }

    public void Anadir_Foto(string foto, string nombre,
                            string autor, string descripcion)
    {
      NpgsqlConnection Conexion = new NpgsqlConnection(Mostrar.sConexion);

      string sOrdenSQL =
        "insert into album (foto, nombre, autor, descripcion) " +
        "values (:foto,:nombre,:autor,:descripcion)";

      NpgsqlCommand OrdenSQL = new NpgsqlCommand(sOrdenSQL, Conexion);

      OrdenSQL.Parameters.Add(new NpgsqlParameter("foto",
        NpgsqlTypes.NpgsqlDbType.Varchar, 30));
      OrdenSQL.Parameters["foto"].Value = foto;

      OrdenSQL.Parameters.Add(new NpgsqlParameter("nombre",
        NpgsqlTypes.NpgsqlDbType.Varchar, 30));
      OrdenSQL.Parameters["nombre"].Value = nombre;

      OrdenSQL.Parameters.Add(new NpgsqlParameter("autor",
        NpgsqlTypes.NpgsqlDbType.Varchar, 30));
      OrdenSQL.Parameters["autor"].Value = autor;

      OrdenSQL.Parameters.Add(new NpgsqlParameter("descripcion",
        NpgsqlTypes.NpgsqlDbType.Varchar, 400));
      OrdenSQL.Parameters["descripcion"].Value = descripcion;

      OrdenSQL.Connection.Open();
      OrdenSQL.ExecuteNonQuery();
      OrdenSQL.Connection.Close();
    }
  }
}
    
