﻿using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.IO;
using Npgsql;

namespace ClienteDeEscritorioFotos
{
  public partial class Mostrar : Form
  {
    // Cadena de conexión con la base de datos
    public const string sConexion =
      "SERVER=localhost;Database=fotos;" +
      "User name=postgres;Password=abcde"; 
    // Conjunto de datos 
    private DataSet ds = null;
    // Ruta de la carpeta "fotos"
    public const string sRutaFotos = "/home/ceballos/";
    public const string sCarpFotos = "fotos";
    private int _iActual = -1; // índice de la foto mostrada

    public Mostrar()
    {
      InitializeComponent();
    }

    private void Mostrar_Load(object sender, EventArgs e)
    {
      if (!Directory.Exists(sRutaFotos))
      {
        MessageBox.Show("No existe la ruta " + sRutaFotos +
                        " para la carpeta \"fotos\". Se crea.");
        Directory.CreateDirectory(sRutaFotos + sCarpFotos);
      }
      RecuperarBD();
      ActualizarFoto();
    }

    private void RecuperarBD()
    {
      NpgsqlConnection Conexion = new NpgsqlConnection(sConexion);
      string sOrdenSQL =
        "select nombre, foto, autor, descripcion from album order by autor";
      try
      {
        NpgsqlDataAdapter adaptador =
          new NpgsqlDataAdapter(sOrdenSQL, Conexion);
        ds = new DataSet("fotos");
        adaptador.Fill(ds);
      }
      catch(Exception e)
      {
        MessageBox.Show(this, "No se puede recuperar las fotos " +
          "de la base de datos.\n\n" + e.Message, "Error BD",
          MessageBoxButtons.OK, MessageBoxIcon.Error);
      }
      finally
      {
        if (Conexion != null) Conexion.Close();
      }
      			
      // Actualizar el índice de la foto si hubiera sido afectado
      // por la operación eliminar foto
      if ((ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0))
      {
        if (_iActual > 0)
          _iActual = (ds.Tables[0].Rows.Count - 1 < _iActual)
            ? _iActual = ds.Tables[0].Rows.Count - 1 : _iActual;
        else
          _iActual = 0;
      }
      else
      {
        _iActual = -1;
      }
    }

    private void ActualizarFoto()
    {
      // Mostrar la foto especificada por _iActual
      // y la información sobre la misma
      if (_iActual == -1)
      {
        this.ciFoto.Image = null;
        this.ctNombre.Text = string.Empty;
        this.ctAutor.Text = string.Empty;
        this.ctDescripcion.Text = string.Empty;
      }
      else
      {
        string sRuta = sRutaFotos + ds.Tables[0].Rows[_iActual]["foto"];
        MemoryStream ms = new MemoryStream(File.ReadAllBytes(sRuta));
        this.ciFoto.Image = Image.FromStream(ms);
        //this.ciFoto.Image = Image.FromFile(sRutaFotos + 
        //  ds.Tables[0].Rows[_iActual]["foto"].ToString());
        this.ctNombre.Text =
          ds.Tables[0].Rows[_iActual]["nombre"].ToString();
        this.ctAutor.Text =
          ds.Tables[0].Rows[_iActual]["autor"].ToString();
        this.ctDescripcion.Text =
          ds.Tables[0].Rows[_iActual]["descripcion"].ToString();
      }
    }

    private void btPrimero_Click(object sender, EventArgs e)
    {
      _iActual = (((ds.Tables.Count > 0) &&
                   (ds.Tables[0].Rows.Count > 0)) ? 0 : -1);
      				
      ActualizarFoto();
    }

    private void btAnterior_Click(object sender, EventArgs e)
    {
      _iActual--;
      if ((ds.Tables.Count > 0) &&
          (ds.Tables[0].Rows.Count > 0) && (_iActual < 0))
        _iActual = 0;
      else if (_iActual < -1)
        _iActual = -1;
      				
      ActualizarFoto();	
    }

    private void btSiguiente_Click(object sender, EventArgs e)
    {
      _iActual++;
      if ((ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0) &&
          (_iActual >= ds.Tables[0].Rows.Count))
        _iActual = ds.Tables[0].Rows.Count - 1;
      else if (_iActual == -1)
        _iActual = -1;
      				
      ActualizarFoto();	
    }

    private void btUltimo_Click(object sender, EventArgs e)
    {
      if ((ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0))
      _iActual = ds.Tables[0].Rows.Count - 1;
      else
        _iActual = -1;
      				
      ActualizarFoto();
    }

    private void añadirFoto_Click(object sender, EventArgs e)
    {
      Añadir formAñadir = new Añadir();
      if (formAñadir.ShowDialog() == DialogResult.OK)
      {
        RecuperarBD();
        ActualizarFoto();
      }
    }

    private void eliminarFoto_Click(object sender, EventArgs e)
    {
      Eliminar formEliminar = new Eliminar();
      if (formEliminar.ShowDialog() == DialogResult.OK)
      {
        RecuperarBD();
        ActualizarFoto();
      }
    }
  }
}
