using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using Npgsql;
using System.IO;

namespace ClienteDeEscritorioFotos
{
  public partial class Aadir : Form
  {
    public Aadir()
    {
      InitializeComponent();
    }

    private void btExaminar_Click(object sender, EventArgs e)
    {
      OpenFileDialog DlgAbrir = new OpenFileDialog();

      DlgAbrir.InitialDirectory = Directory.GetCurrentDirectory();
      DlgAbrir.Filter =
        "Ficheros BMP|*.bmp;*.BMP"+
        "|Ficheros GIF|*.gif;*.GIF"+
        "|Ficheros JPG o JPEG|*.jpg;*.JPG;*.jpeg;*.JPEG"+
        "|Ficheros PNG|*.png;*.PNG"+
        "|Ficheros EXIF|*.exif;*.EXIF"+
        "|Ficheros TIFF|*.tiff;*.TIFF"+
        "|(*.*)|*.*";
      DlgAbrir.FilterIndex = 3;

      // Mostrar el dilogo Abrir
      if (DlgAbrir.ShowDialog() == DialogResult.OK)
      {
        ctRutaFoto.Text = DlgAbrir.FileName;
      }
    }

    private void btAadir_Click(object sender, EventArgs e)
    {
      if (FormularioCorrecto())
      {
        FileStream fs = null; // para leer el fichero imagen
        // Obtener la ruta de la caja de texto
        FileInfo fiFoto = new FileInfo(ctRutaFoto.Text.Trim());
        // Comprobar si el fichero existe
        if (fiFoto.Exists)
        {
          try
          {
            // Subir la foto al servidor y guardar sus datos en la BD
            byte[] bImg = new byte[fiFoto.Length];
            fs = fiFoto.Open(FileMode.Open);
            fs.Read(bImg, 0, (int)fs.Length);
            // Invocar al mtodo AgregarFoto del servicio Web
						rServWebFotos.ServWebFotos servicio =
              new rServWebFotos.ServWebFotos();
            servicio.AgregarFoto(fiFoto.Name, ctNombre.Text,
              ctAutor.Text, ctDescripcion.Text, bImg);

            MessageBox.Show(this, "Foto aadida: " + ctNombre.Text,
                            "Nueva foto", MessageBoxButtons.OK,
                            MessageBoxIcon.Information);

            this.Close();
          }
          catch
          {
            MessageBox.Show(this, "Error al aadir la foto: " + 
              ctNombre.Text, "Nueva foto",
              MessageBoxButtons.OK, MessageBoxIcon.Error);
          }
					finally
					{
						if (fs != null) fs.Close();
					}
        }
      }
    }

    protected bool FormularioCorrecto()
    {
      bool bArchivoCorrecto = true;
      bool bNombreCorrecto = true;
      bool bAutorCorrecto = true;
      string mensajeError = null;

      // Comprobamos los datos del formulario
      if (ctRutaFoto.Text.Length == 0)
      {
        mensajeError = "Seleccione un archivo";
        bArchivoCorrecto = false;
      }
      if (ctAutor.Text.Length == 0)
      {
        mensajeError += "\nDebe introducir un autor";
        bAutorCorrecto = false;
      }
      if (ctNombre.Text.Length == 0)
      {
        mensajeError += "\nDebe introducir un nombre";
        bNombreCorrecto = false;
      }

      if (!(bArchivoCorrecto && bNombreCorrecto && bAutorCorrecto))
        MessageBox.Show(mensajeError);
      return (bArchivoCorrecto && bNombreCorrecto && bAutorCorrecto);
    }
  }
}
    